/* language.c
 * Copyright (C) 2007-2008 Gauvain Pocentek <gpocentek@linutop.com>
 * This file is part of the linutop config editor
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __UTILS_H__
#define __UTILS_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef HAVE_STIDO_H
#include <stdio.h>
#endif
#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#ifdef HAVE_SYS_STAT_H
#include <sys/stat.h>
#endif
#ifdef HAVE_SYS_TYPES_H
#include <sys/types.h>
#endif
#ifdef HAVE_PWD_H
#include <pwd.h>
#endif

#include <glib/gstdio.h>
#include <libxklavier/xklavier.h>

#include <libxfcegui4.h>
#include <ltop_os_info.h>

#define README "/cdrom/readme.txt"
#define REBOOTCMD "shutdown -r now"

struct resolution {
    const gchar *code;
    const gchar *display;
};
extern const struct resolution resolutions[];

enum {
    VIDEO_CRT = 1,
    VIDEO_DVI,
    VIDEO_CRT_DVI,
    VIDEO_DVI_CRT,
    VIDEO_INVALID
};
struct videooutput {
    int code;
    const char *display;
};
extern const struct videooutput videooutputs[];

struct locale_item {
    const gchar *name;
    const gchar *code;
    const gchar *kbd;
    const gchar *tz;
};
extern const struct locale_item locale_data[];

enum {
    LID_NONE = 0,
    LID_SUSPEND,
    LID_HALT,
    LID_NB
};

#define IS_L3  (dialog->os_info->machine == LTOP_MACHINE_L3) ? TRUE : FALSE
#define IS_L2  (dialog->os_info->machine == LTOP_MACHINE_L2) ? TRUE : FALSE
#define IS_EEE (dialog->os_info->machine == LTOP_MACHINE_EEE) ? TRUE : FALSE

#ifdef WITH_DEMO
#define DEMO_SET_SENSITIVE(widget) gtk_widget_set_sensitive ((widget), FALSE)
#else
#define DEMO_SET_SENSITIVE(widget)
#endif

Display *dsp;
XklEngine *engine;
XklConfigRegistry *registry;
XklConfigRec *user_rec_config;

/* Prototypes */
inline gint _system (gchar *cmd);

void      cb_row_activated    (GtkWidget * dialog,
                               gpointer data);
GtkWidget *get_image_from_str (const gchar *str);
GtkWidget *new_run_cmd_button (const gchar *icon, const gchar *txt,
                               const gchar *app, gboolean as_user);

gboolean  app_is_usable       (const gchar *app);
gchar    *get_home            (void);
void      run_user_cmd        (const char *user_cmd,
                               gboolean sn);
gchar    *get_locale_name     (const gchar *code);
gchar    *get_kbd_name        (const gchar *str);

void      apply_kbd_config    (const gchar * kbd);

void      get_from_language   (const gchar *locale,
                               gchar **kbd, gchar **tz);

gchar    *get_bashstyle_config (const gchar *conffile,
                                const gchar *key,
                                const gchar *fallback);
void      set_bashstyle_config (const gchar *conffile,
                                const gchar *key,
                                const gchar *value);

gboolean  get_service_is_blacklisted (const gchar *service);

gboolean  get_autostart_infos (gchar **command, gchar **icon);

void      restore_dialog_run ();

gboolean reboot_scheduled (guint *hours, guint *minutes);

#endif /* __UTILS_H__ */
